@@ -3,7 +3,7 @@ AUTHORS = ('Author Information', {
 })
 
 PUBLICATION = ('Publication Information', {
-    'fields': ('pub_date', 'pub_status', 'sites', ),
+    'fields': ('pub_date', 'pub_status', 'sites', 'access'),
 })
 
 TAXONOMY = ('Taxonomy', {
